@@ -64,8 +64,6 @@ as.vega.ggvis <- function(x, session = NULL, dynamic = FALSE, ...) {
     data = c(datasets, scale_datasets),
     scales = lapply(unname(x$scales), as.vega),
     marks = lapply(x$marks, as.vega),
-    width = x$options$width,
-    height = x$options$height,
     legends = compact(lapply(x$legends, as.vega)),
     axes = compact(lapply(x$axes, as.vega)),
     padding = as.vega(x$options$padding),
@@ -119,7 +117,7 @@ as.vega.mark <- function(mark, in_group = FALSE) {
   properties$ggvis$data <- list(value = data_id)
 
   group_vars <- dplyr::groups(shiny::isolate(mark$data()))
-  if (!in_group && !is.null(group_vars)) {
+  if (!in_group && length(group_vars)) {
     # FIXME: probably should go away and just use subvis
 
     # String representation of groups
